api.authentication.v1.test_helpers.totp package — Argus-Toolbelt 1.0 documentation

# api.authentication.v1.test_helpers.totp package

## Submodules

## api.authentication.v1.test_helpers.totp.authenticate module

`api.authentication.v1.test_helpers.totp.authenticate.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/totp/authenticate, respond with HTTP 403

`api.authentication.v1.test_helpers.totp.authenticate.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/totp/authenticate, respond with HTTP 404

`api.authentication.v1.test_helpers.totp.authenticate.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/totp/authenticate, respond with HTTP 200

`api.authentication.v1.test_helpers.totp.authenticate.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/totp/authenticate, respond with HTTP 401

## api.authentication.v1.test_helpers.totp.initialize module

`api.authentication.v1.test_helpers.totp.initialize.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/totp, respond with HTTP 403

`api.authentication.v1.test_helpers.totp.initialize.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/totp, respond with HTTP 404

`api.authentication.v1.test_helpers.totp.initialize.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/totp, respond with HTTP 200

`api.authentication.v1.test_helpers.totp.initialize.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/totp, respond with HTTP 401

## api.authentication.v1.test_helpers.totp.revoke module

`api.authentication.v1.test_helpers.totp.revoke.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/totp, respond with HTTP 403

`api.authentication.v1.test_helpers.totp.revoke.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/totp, respond with HTTP 404

`api.authentication.v1.test_helpers.totp.revoke.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/totp, respond with HTTP 200

`api.authentication.v1.test_helpers.totp.revoke.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/totp, respond with HTTP 401

## api.authentication.v1.test_helpers.totp.verify module

`api.authentication.v1.test_helpers.totp.verify.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/totp, respond with HTTP 403

`api.authentication.v1.test_helpers.totp.verify.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/totp, respond with HTTP 404

`api.authentication.v1.test_helpers.totp.verify.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/totp, respond with HTTP 200

`api.authentication.v1.test_helpers.totp.verify.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/totp, respond with HTTP 401

## Module contents